vfbLib.parsers.guides.GuidePropertiesParser
===========================================

.. currentmodule:: vfbLib.parsers.guides

.. autoclass:: GuidePropertiesParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GuidePropertiesParser.__init__
      ~GuidePropertiesParser.parse
      ~GuidePropertiesParser.parse_hex
      ~GuidePropertiesParser.read_double
      ~GuidePropertiesParser.read_doubles
      ~GuidePropertiesParser.read_float
      ~GuidePropertiesParser.read_floats
      ~GuidePropertiesParser.read_int16
      ~GuidePropertiesParser.read_int32
      ~GuidePropertiesParser.read_int8
      ~GuidePropertiesParser.read_str
      ~GuidePropertiesParser.read_str_all
      ~GuidePropertiesParser.read_uint16
      ~GuidePropertiesParser.read_uint32
      ~GuidePropertiesParser.read_uint8
      ~GuidePropertiesParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GuidePropertiesParser.encoding
      ~GuidePropertiesParser.master_count
      ~GuidePropertiesParser.stream
      ~GuidePropertiesParser.ttStemsH_count
      ~GuidePropertiesParser.ttStemsV_count
   
   